# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from proto import data_logger_service_pb2 as proto_dot_data__logger__service__pb2


class DataLoggerServiceStub(object):
  """The service that provides an endpoint to store various entities to Google
  Cloud Data Store.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.PutCompetition = channel.unary_unary(
        '/org.powertac.samplebroker.api.DataLoggerService/PutCompetition',
        request_serializer=proto_dot_data__logger__service__pb2.PutCompetitionRequest.SerializeToString,
        response_deserializer=proto_dot_data__logger__service__pb2.PutCompetitionResponse.FromString,
        )


class DataLoggerServiceServicer(object):
  """The service that provides an endpoint to store various entities to Google
  Cloud Data Store.
  """

  def PutCompetition(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DataLoggerServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'PutCompetition': grpc.unary_unary_rpc_method_handler(
          servicer.PutCompetition,
          request_deserializer=proto_dot_data__logger__service__pb2.PutCompetitionRequest.FromString,
          response_serializer=proto_dot_data__logger__service__pb2.PutCompetitionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'org.powertac.samplebroker.api.DataLoggerService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
