# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/market_transaction_model.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/market_transaction_model.proto',
  package='org.powertac.samplebroker',
  syntax='proto3',
  serialized_pb=_b('\n$proto/market_transaction_model.proto\x12\x19org.powertac.samplebroker\"e\n\x18PredictLimitPriceRequest\x12I\n\x05state\x18\x01 \x01(\x0b\x32:.org.powertac.samplebroker.WholesaleMarketEnvironmentState\"0\n\x19PredictLimitPriceResponse\x12\x13\n\x0blimit_price\x18\x01 \x01(\x01\"\xff\x01\n\x16PutStateHistoryRequest\x12I\n\x05state\x18\x01 \x01(\x0b\x32:.org.powertac.samplebroker.WholesaleMarketEnvironmentState\x12M\n\tnew_state\x18\x02 \x01(\x0b\x32:.org.powertac.samplebroker.WholesaleMarketEnvironmentState\x12\x1d\n\x15predicted_limit_price\x18\x03 \x01(\x01\x12\x1b\n\x13\x63leared_limit_price\x18\x04 \x01(\x01\x12\x0f\n\x07\x63leared\x18\x05 \x01(\x08\"\x19\n\x17PutStateHistoryResponse\"\x93\x01\n\x1fWholesaleMarketEnvironmentState\x12\x13\n\x0bhour_of_day\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x61y_of_week\x18\x02 \x01(\x05\x12\"\n\x1ahour_of_day_for_prediction\x18\x03 \x01(\x05\x12\"\n\x1a\x64\x61y_of_week_for_prediction\x18\x04 \x01(\x05\x32\x97\x02\n\x16MarketTransactionModel\x12\x80\x01\n\x11PredictLimitPrice\x12\x33.org.powertac.samplebroker.PredictLimitPriceRequest\x1a\x34.org.powertac.samplebroker.PredictLimitPriceResponse\"\x00\x12z\n\x0fPutStateHistory\x12\x31.org.powertac.samplebroker.PutStateHistoryRequest\x1a\x32.org.powertac.samplebroker.PutStateHistoryResponse\"\x00\x42\x36\n\x19org.powertac.samplebrokerB\x11MarketTransactionP\x01\xa2\x02\x03\x42UNb\x06proto3')
)




_PREDICTLIMITPRICEREQUEST = _descriptor.Descriptor(
  name='PredictLimitPriceRequest',
  full_name='org.powertac.samplebroker.PredictLimitPriceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='org.powertac.samplebroker.PredictLimitPriceRequest.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=168,
)


_PREDICTLIMITPRICERESPONSE = _descriptor.Descriptor(
  name='PredictLimitPriceResponse',
  full_name='org.powertac.samplebroker.PredictLimitPriceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit_price', full_name='org.powertac.samplebroker.PredictLimitPriceResponse.limit_price', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=218,
)


_PUTSTATEHISTORYREQUEST = _descriptor.Descriptor(
  name='PutStateHistoryRequest',
  full_name='org.powertac.samplebroker.PutStateHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='org.powertac.samplebroker.PutStateHistoryRequest.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_state', full_name='org.powertac.samplebroker.PutStateHistoryRequest.new_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='predicted_limit_price', full_name='org.powertac.samplebroker.PutStateHistoryRequest.predicted_limit_price', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cleared_limit_price', full_name='org.powertac.samplebroker.PutStateHistoryRequest.cleared_limit_price', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cleared', full_name='org.powertac.samplebroker.PutStateHistoryRequest.cleared', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=476,
)


_PUTSTATEHISTORYRESPONSE = _descriptor.Descriptor(
  name='PutStateHistoryResponse',
  full_name='org.powertac.samplebroker.PutStateHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=503,
)


_WHOLESALEMARKETENVIRONMENTSTATE = _descriptor.Descriptor(
  name='WholesaleMarketEnvironmentState',
  full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hour_of_day', full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState.hour_of_day', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='day_of_week', full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState.day_of_week', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hour_of_day_for_prediction', full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState.hour_of_day_for_prediction', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='day_of_week_for_prediction', full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState.day_of_week_for_prediction', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=506,
  serialized_end=653,
)

_PREDICTLIMITPRICEREQUEST.fields_by_name['state'].message_type = _WHOLESALEMARKETENVIRONMENTSTATE
_PUTSTATEHISTORYREQUEST.fields_by_name['state'].message_type = _WHOLESALEMARKETENVIRONMENTSTATE
_PUTSTATEHISTORYREQUEST.fields_by_name['new_state'].message_type = _WHOLESALEMARKETENVIRONMENTSTATE
DESCRIPTOR.message_types_by_name['PredictLimitPriceRequest'] = _PREDICTLIMITPRICEREQUEST
DESCRIPTOR.message_types_by_name['PredictLimitPriceResponse'] = _PREDICTLIMITPRICERESPONSE
DESCRIPTOR.message_types_by_name['PutStateHistoryRequest'] = _PUTSTATEHISTORYREQUEST
DESCRIPTOR.message_types_by_name['PutStateHistoryResponse'] = _PUTSTATEHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['WholesaleMarketEnvironmentState'] = _WHOLESALEMARKETENVIRONMENTSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictLimitPriceRequest = _reflection.GeneratedProtocolMessageType('PredictLimitPriceRequest', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTLIMITPRICEREQUEST,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.PredictLimitPriceRequest)
  ))
_sym_db.RegisterMessage(PredictLimitPriceRequest)

PredictLimitPriceResponse = _reflection.GeneratedProtocolMessageType('PredictLimitPriceResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTLIMITPRICERESPONSE,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.PredictLimitPriceResponse)
  ))
_sym_db.RegisterMessage(PredictLimitPriceResponse)

PutStateHistoryRequest = _reflection.GeneratedProtocolMessageType('PutStateHistoryRequest', (_message.Message,), dict(
  DESCRIPTOR = _PUTSTATEHISTORYREQUEST,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.PutStateHistoryRequest)
  ))
_sym_db.RegisterMessage(PutStateHistoryRequest)

PutStateHistoryResponse = _reflection.GeneratedProtocolMessageType('PutStateHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUTSTATEHISTORYRESPONSE,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.PutStateHistoryResponse)
  ))
_sym_db.RegisterMessage(PutStateHistoryResponse)

WholesaleMarketEnvironmentState = _reflection.GeneratedProtocolMessageType('WholesaleMarketEnvironmentState', (_message.Message,), dict(
  DESCRIPTOR = _WHOLESALEMARKETENVIRONMENTSTATE,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.WholesaleMarketEnvironmentState)
  ))
_sym_db.RegisterMessage(WholesaleMarketEnvironmentState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\031org.powertac.samplebrokerB\021MarketTransactionP\001\242\002\003BUN'))

_MARKETTRANSACTIONMODEL = _descriptor.ServiceDescriptor(
  name='MarketTransactionModel',
  full_name='org.powertac.samplebroker.MarketTransactionModel',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=656,
  serialized_end=935,
  methods=[
  _descriptor.MethodDescriptor(
    name='PredictLimitPrice',
    full_name='org.powertac.samplebroker.MarketTransactionModel.PredictLimitPrice',
    index=0,
    containing_service=None,
    input_type=_PREDICTLIMITPRICEREQUEST,
    output_type=_PREDICTLIMITPRICERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PutStateHistory',
    full_name='org.powertac.samplebroker.MarketTransactionModel.PutStateHistory',
    index=1,
    containing_service=None,
    input_type=_PUTSTATEHISTORYREQUEST,
    output_type=_PUTSTATEHISTORYRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MARKETTRANSACTIONMODEL)

DESCRIPTOR.services_by_name['MarketTransactionModel'] = _MARKETTRANSACTIONMODEL

try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities


  class MarketTransactionModelStub(object):
    """The market transaction model service definition.
    """

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.PredictLimitPrice = channel.unary_unary(
          '/org.powertac.samplebroker.MarketTransactionModel/PredictLimitPrice',
          request_serializer=PredictLimitPriceRequest.SerializeToString,
          response_deserializer=PredictLimitPriceResponse.FromString,
          )
      self.PutStateHistory = channel.unary_unary(
          '/org.powertac.samplebroker.MarketTransactionModel/PutStateHistory',
          request_serializer=PutStateHistoryRequest.SerializeToString,
          response_deserializer=PutStateHistoryResponse.FromString,
          )


  class MarketTransactionModelServicer(object):
    """The market transaction model service definition.
    """

    def PredictLimitPrice(self, request, context):
      """Send a request to predict current states
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def PutStateHistory(self, request, context):
      """TODO
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_MarketTransactionModelServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'PredictLimitPrice': grpc.unary_unary_rpc_method_handler(
            servicer.PredictLimitPrice,
            request_deserializer=PredictLimitPriceRequest.FromString,
            response_serializer=PredictLimitPriceResponse.SerializeToString,
        ),
        'PutStateHistory': grpc.unary_unary_rpc_method_handler(
            servicer.PutStateHistory,
            request_deserializer=PutStateHistoryRequest.FromString,
            response_serializer=PutStateHistoryResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'org.powertac.samplebroker.MarketTransactionModel', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class BetaMarketTransactionModelServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """The market transaction model service definition.
    """
    def PredictLimitPrice(self, request, context):
      """Send a request to predict current states
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def PutStateHistory(self, request, context):
      """TODO
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaMarketTransactionModelStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """The market transaction model service definition.
    """
    def PredictLimitPrice(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Send a request to predict current states
      """
      raise NotImplementedError()
    PredictLimitPrice.future = None
    def PutStateHistory(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """TODO
      """
      raise NotImplementedError()
    PutStateHistory.future = None


  def beta_create_MarketTransactionModel_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): PredictLimitPriceRequest.FromString,
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): PutStateHistoryRequest.FromString,
    }
    response_serializers = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): PredictLimitPriceResponse.SerializeToString,
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): PutStateHistoryResponse.SerializeToString,
    }
    method_implementations = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): face_utilities.unary_unary_inline(servicer.PredictLimitPrice),
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): face_utilities.unary_unary_inline(servicer.PutStateHistory),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_MarketTransactionModel_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): PredictLimitPriceRequest.SerializeToString,
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): PutStateHistoryRequest.SerializeToString,
    }
    response_deserializers = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): PredictLimitPriceResponse.FromString,
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): PutStateHistoryResponse.FromString,
    }
    cardinalities = {
      'PredictLimitPrice': cardinality.Cardinality.UNARY_UNARY,
      'PutStateHistory': cardinality.Cardinality.UNARY_UNARY,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'org.powertac.samplebroker.MarketTransactionModel', cardinalities, options=stub_options)
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)
