# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/competition.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/competition.proto',
  package='org.powertac.samplebroker.api',
  syntax='proto3',
  serialized_pb=_b('\n\x17proto/competition.proto\x12\x1dorg.powertac.samplebroker.api\"\xbd\x02\n\x0b\x43ompetition\x12\x16\n\x0e\x63ompetition_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x14minimumTimeslotCount\x18\x03 \x01(\x05\x12\x1d\n\x15\x65xpectedTimeslotCount\x18\x04 \x01(\x05\x12\x1c\n\x14minimumOrderQuantity\x18\x05 \x01(\x01\x12#\n\x1bmaxUpRegulationPaymentRatio\x18\x06 \x01(\x01\x12\x1c\n\x14upRegulationDiscount\x18\x07 \x01(\x01\x12%\n\x1dmaxDownRegulationPaymentRatio\x18\x08 \x01(\x01\x12\x1e\n\x16\x64ownRegulationDiscount\x18\t \x01(\x01\x12#\n\x1b\x65stimatedConsumptionPremium\x18\n \x01(\x01\x62\x06proto3')
)




_COMPETITION = _descriptor.Descriptor(
  name='Competition',
  full_name='org.powertac.samplebroker.api.Competition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='competition_id', full_name='org.powertac.samplebroker.api.Competition.competition_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.powertac.samplebroker.api.Competition.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minimumTimeslotCount', full_name='org.powertac.samplebroker.api.Competition.minimumTimeslotCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expectedTimeslotCount', full_name='org.powertac.samplebroker.api.Competition.expectedTimeslotCount', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minimumOrderQuantity', full_name='org.powertac.samplebroker.api.Competition.minimumOrderQuantity', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxUpRegulationPaymentRatio', full_name='org.powertac.samplebroker.api.Competition.maxUpRegulationPaymentRatio', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upRegulationDiscount', full_name='org.powertac.samplebroker.api.Competition.upRegulationDiscount', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxDownRegulationPaymentRatio', full_name='org.powertac.samplebroker.api.Competition.maxDownRegulationPaymentRatio', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='downRegulationDiscount', full_name='org.powertac.samplebroker.api.Competition.downRegulationDiscount', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='estimatedConsumptionPremium', full_name='org.powertac.samplebroker.api.Competition.estimatedConsumptionPremium', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=376,
)

DESCRIPTOR.message_types_by_name['Competition'] = _COMPETITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Competition = _reflection.GeneratedProtocolMessageType('Competition', (_message.Message,), dict(
  DESCRIPTOR = _COMPETITION,
  __module__ = 'proto.competition_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.api.Competition)
  ))
_sym_db.RegisterMessage(Competition)


try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)
