# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/simulation_job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/simulation_job.proto',
  package='org.powertac.samplebroker.bunnieinfra',
  syntax='proto3',
  serialized_pb=_b('\n\x1aproto/simulation_job.proto\x12%org.powertac.samplebroker.bunnieinfra\"\x90\x04\n\rSimulationJob\x12K\n\x06status\x18\x01 \x01(\x0e\x32;.org.powertac.samplebroker.bunnieinfra.SimulationJob.Status\x12L\n\x07\x62rokers\x18\x02 \x03(\x0b\x32;.org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker\x12Z\n\x0e\x62ootstrap_file\x18\x03 \x01(\x0b\x32\x42.org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile\x12\x15\n\rexperiment_id\x18\x04 \x01(\x03\x1a,\n\x06\x42roker\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64ocker_image\x18\x02 \x01(\t\x1aV\n\rBootstrapFile\x12(\n google_cloud_storage_bucket_name\x18\x01 \x01(\t\x12\x1b\n\x13\x62ootstrap_file_path\x18\x02 \x01(\t\"k\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x10\n\x0cSTATUS_READY\x10\x01\x12\x12\n\x0eSTATUS_RUNNING\x10\x02\x12\x14\n\x10STATUS_COMPLETED\x10\x03\x12\x11\n\rSTATUS_FAILED\x10\x04\x62\x06proto3')
)



_SIMULATIONJOB_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATUS_READY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATUS_RUNNING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATUS_COMPLETED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATUS_FAILED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=491,
  serialized_end=598,
)
_sym_db.RegisterEnumDescriptor(_SIMULATIONJOB_STATUS)


_SIMULATIONJOB_BROKER = _descriptor.Descriptor(
  name='Broker',
  full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='docker_image', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker.docker_image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=401,
)

_SIMULATIONJOB_BOOTSTRAPFILE = _descriptor.Descriptor(
  name='BootstrapFile',
  full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='google_cloud_storage_bucket_name', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile.google_cloud_storage_bucket_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bootstrap_file_path', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile.bootstrap_file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=489,
)

_SIMULATIONJOB = _descriptor.Descriptor(
  name='SimulationJob',
  full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='brokers', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.brokers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bootstrap_file', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.bootstrap_file', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.experiment_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SIMULATIONJOB_BROKER, _SIMULATIONJOB_BOOTSTRAPFILE, ],
  enum_types=[
    _SIMULATIONJOB_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=598,
)

_SIMULATIONJOB_BROKER.containing_type = _SIMULATIONJOB
_SIMULATIONJOB_BOOTSTRAPFILE.containing_type = _SIMULATIONJOB
_SIMULATIONJOB.fields_by_name['status'].enum_type = _SIMULATIONJOB_STATUS
_SIMULATIONJOB.fields_by_name['brokers'].message_type = _SIMULATIONJOB_BROKER
_SIMULATIONJOB.fields_by_name['bootstrap_file'].message_type = _SIMULATIONJOB_BOOTSTRAPFILE
_SIMULATIONJOB_STATUS.containing_type = _SIMULATIONJOB
DESCRIPTOR.message_types_by_name['SimulationJob'] = _SIMULATIONJOB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimulationJob = _reflection.GeneratedProtocolMessageType('SimulationJob', (_message.Message,), dict(

  Broker = _reflection.GeneratedProtocolMessageType('Broker', (_message.Message,), dict(
    DESCRIPTOR = _SIMULATIONJOB_BROKER,
    __module__ = 'proto.simulation_job_pb2'
    # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker)
    ))
  ,

  BootstrapFile = _reflection.GeneratedProtocolMessageType('BootstrapFile', (_message.Message,), dict(
    DESCRIPTOR = _SIMULATIONJOB_BOOTSTRAPFILE,
    __module__ = 'proto.simulation_job_pb2'
    # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile)
    ))
  ,
  DESCRIPTOR = _SIMULATIONJOB,
  __module__ = 'proto.simulation_job_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.bunnieinfra.SimulationJob)
  ))
_sym_db.RegisterMessage(SimulationJob)
_sym_db.RegisterMessage(SimulationJob.Broker)
_sym_db.RegisterMessage(SimulationJob.BootstrapFile)


try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)
